Directory check
check_dir.RdDirectory check
Details
Check that
The user knows that the data will not be saved if
dir = NULL.The directory exists if it can be created.
The function fails if the directory cannot be created.
See also
Other helper function:
Format.AKSlope.fn(),
check_survey(),
combine_tows(),
createMatrix(),
filter_pull()