Survey name matching function used when pull from the data warehouse
createMatrix.RdSurvey name matching function used when pull from the data warehouse
See also
Other helper function:
Format.AKSlope.fn(),
check_dir(),
check_survey(),
combine_tows(),
filter_pull()