Skip to contents

Plot the representativeness of age sampling based on lengths

Usage

plot_age_length_sampling(
  data,
  dir = NULL,
  plot = 1:2,
  height = 7,
  width = 7,
  xlim = lifecycle::deprecated(),
  ylim = lifecycle::deprecated()
)

Arguments

data

A data frame of composition data returned from pull_bio().

dir

Defaults to NULL (plot made, but not saved to file). Can alternatively be a string filename by year and sex.

plot

A vector of integers to specify which plots to return. The default is to print or save all figures, i.e., plot = 1:2. Integers correspond to the following figures:

  1. Compare distribution of all lengths and lengths from aged fish across all years

  2. Compare distribution of all lengths and lengths from aged fish across by year

width, height

Numeric values for the figure width and height in inches. The defaults are 7 by 7 inches.

xlim

Deprecated as of v.2.8.1. x limits for plot, defaults to c(0,120)

ylim

Deprecated as of v.2.8.1. y limits for plot, defaults to (0, 0.049)

Author

Chantel Wetzel