Skip to contents

Plot variability of length at age

Usage

plot_var_length_at_age(
  data,
  age_bins,
  dir = NULL,
  main = NULL,
  two_sex = TRUE,
  height = 7,
  width = 7
)

Arguments

data

A data frame of length-composition data returned from pull_bio().

age_bins

Vector of integers to bin age data.Values above or below the minimum or maximum values in the vector are grouped into the first size or plus group size, respectively.

dir

Defaults to NULL (plot made, but not saved to file). Can alternatively be a string filename by year and sex.

main

Name that will be used to name the saved png

two_sex

Logical to indicate if plot by sex. Default is TRUE and will only plot females and males.

width, height

Numeric values for the figure width and height in inches. The defaults are 7 by 7 inches.

Author

Chantel Wetzel