Create strata data frame using get_strata_areas
create_strata.RdCreate strata data frame using get_strata_areas
Arguments
- names
A vector of character values providing a name for each strata; if left at the default value of
NA, then names will be created using capital letters starting withAfor eachNAvalue.- depths_shallow
vector of the shallow depths splits for each strata
- depths_deep
vector of the deep depths splits for each strata
- lats_south
vector of the southern latitude splits for each strata
- lats_north
vector of the northern latitude splits for each strata
Value
Returns the data frame formatted for use by get_design_based
and additional prediction functions in other downstream packages.
The data frame will have six columns,
(1) name, (2) area, (3) Depth_m.1, (4) Depth_m.2,
(5) Latitude_dd.1, and (6) Latitude_dd.2.
Details
Create a data frame of strata formatted for use by models that need estimates of the area for each strata to expand estimates of abundance. Strata limits are provided by the user in terms of and east and west ranges using depth (shallow and deep, respectively) and north and south ranges using latitudes.
See also
See get_strata_areas for how areas are calculated.
See get_design_based for how the areas are used to create design-based biomass estimates.
Other strata function:
CreateStrataDF.fn()