Plot two figures showing catch-per-unit-effort data
plot_cpue_map.RdPlot catch-per-unit-effort (CPUE) data across all years and by year and save them to the disk. Figures are created using ggplot2.
Arguments
- data
A dataframe of catch data created by
pull_catch().- dir
Directory where output will be saved. The directory where the file should be saved. If dir = NULL no output will be saved.
- main
A string that will be prepended to the name of the saved png (i.e., "NWFSC" results in a file called "NWFSC_CPUE_Map.png").
- plot
A vector of integers to specify which plots you would like. The default is to print both figures.
coastwide data across all years
coastwide data by year
Value
Figures are saved to the disk according to which plots are asked
for in plot. Each of the specified files are saved to dir, the specified
directory. No objects are returned to the user. But, the figures are printed
to new windows if they are not saved to the disk.