Plot the United States west coast using ggplot2
plot_westcoast.RdPlot the United States west coast such that it can used as a standalone figure or as a base to plot data points on.
See also
plot_cpue_map()uses this function as the base map.
Other plot_:
PlotSexRatio.fn(),
PlotVarLengthAtAge.fn(),
plot_comps(),
plot_cpue(),
plot_cpue_map(),
plot_index(),
plot_length_age(),
plot_proportion(),
plot_sex_ratio(),
plot_sex_ratio_strata(),
plot_varlenage(),
plot_weight_length()