Sql pull of species names
pull_spp.RdA static version of the sql call to pull species taxonomic information from the data warehouse.
Pull common name and scientific name information from the data warehouse.
pull_spp.RdA static version of the sql call to pull species taxonomic information from the data warehouse.
Pull common name and scientific name information from the data warehouse.