Creates a vector of strata factors by request column names
strata_factors.RdCreates a vector of strata factors by request column names
Usage
strata_factors(data, strata_df, strata_vars = c("Latitude_dd", "Depth_m"))Arguments
- data
Catch dataframe created by [pull_catch()]
- strata_df
Strata dataframe created by
create_strata()- strata_vars
Column names in
datato define the stratas by. The default columns areDepth_mordepth_mandLatitude_ddorlatitude_dd.